pub enum Error {
Show 25 variants
Config(String),
Drive(Error),
DriveProofError(ProofError, Vec<u8>, BlockInfo),
Protocol(ProtocolError),
Proof(Error),
InvalidProvedResponse(String),
DapiClientError(DapiClientError),
DapiMocksError(MockError),
CoreError(Error),
MerkleBlockError(MerkleBlockError),
CoreClientError(Error),
MissingDependency(String, String),
TotalCreditsNotFound,
EpochNotFound,
TimeoutReached(Duration, String),
AlreadyExists(String),
InvalidCreditTransfer(String),
NonceOverflow(u64),
IdentityNonceNotFound(String),
Generic(String),
ContextProviderError(ContextProviderError),
Cancelled(String),
StaleNode(StaleNodeError),
StateTransitionBroadcastError(StateTransitionBroadcastError),
NoAvailableAddressesToRetry(Box<Error>),
}Expand description
Error type for the SDK
Variants
Config(String)
SDK is not configured properly
Drive(Error)
Drive error
DriveProofError(ProofError, Vec<u8>, BlockInfo)
Drive proof error with associated proof bytes and block info
Protocol(ProtocolError)
DPP error
Proof(Error)
Proof verification error
InvalidProvedResponse(String)
Invalid Proved Response error
DapiClientError(DapiClientError)
DAPI client error, for example, connection error
DapiMocksError(MockError)
DAPI mocks error
CoreError(Error)
Dash core error
MerkleBlockError(MerkleBlockError)
MerkleBlockError
CoreClientError(Error)
Core client error, for example, connection error
MissingDependency(String, String)
Dependency not found, for example data contract for a document not found
TotalCreditsNotFound
Total credits in Platform are not found; we must always have credits in Platform
EpochNotFound
Epoch not found; we must have at least one epoch
TimeoutReached(Duration, String)
SDK operation timeout reached error
AlreadyExists(String)
Returned when an attempt is made to create an object that already exists in the system
InvalidCreditTransfer(String)
Invalid credit transfer configuration
NonceOverflow(u64)
Identity nonce overflow: the nonce has reached its maximum value and cannot be incremented further without wrapping to zero.
IdentityNonceNotFound(String)
Identity nonce not found on Platform.
Platform returned no nonce for the requested identity (or identity– contract pair). This usually means the queried DAPI node has not yet indexed the identity — for example right after identity creation or when the node is lagging behind the chain tip.
Recovery: retry the state transition; the SDK will re-fetch the nonce from a (potentially different) DAPI node on the next attempt.
Generic(String)
Generic error
ContextProviderError(ContextProviderError)
Context provider error
Cancelled(String)
Operation cancelled - cancel token was triggered, timeout, etc.
StaleNode(StaleNodeError)
Remote node is stale; try another server
StateTransitionBroadcastError(StateTransitionBroadcastError)
Error returned when trying to broadcast a state transition
NoAvailableAddressesToRetry(Box<Error>)
All available addresses have been exhausted (banned due to errors). Contains the last meaningful error that caused addresses to be banned.