GrpcContextProvider

Struct GrpcContextProvider 

pub struct GrpcContextProvider {
    pub data_contracts_cache: Cache<Identifier, DataContract>,
    pub token_configurations_cache: Cache<Identifier, TokenConfiguration>,
    pub quorum_public_keys_cache: Cache<([u8; 32], u32), [u8; 48]>,
    pub dump_dir: Option<PathBuf>,
    /* private fields */
}
Context provider that uses the Core RPC API and the Sdk to fetch data.

Example ContextProvider used by the Sdk for testing purposes.

Fields

data_contracts_cache: Cache<Identifier, DataContract>

Data contracts cache.

Users can insert new data contracts into the cache using Cache::put.

token_configurations_cache: Cache<Identifier, TokenConfiguration>

Token configurations cache.

Users can insert new token configurations into the cache using Cache::put.

quorum_public_keys_cache: Cache<([u8; 32], u32), [u8; 48]>

Quorum public keys cache.

Key is a tuple of quorum hash and quorum type. Value is a quorum public key.

Users can insert new quorum public keys into the cache using Cache::put.

dump_dir: Option<PathBuf>

Directory where to store dumped data.

This is used to store data that is fetched from Platform and can be used for testing purposes.

Implementations

Source

impl GrpcContextProvider

pub fn new( sdk: Option<Sdk>, core_ip: &str, core_port: u16, core_user: &str, core_password: &str, data_contracts_cache_size: NonZeroUsize, token_config_cache_size: NonZeroUsize, quorum_public_keys_cache_size: NonZeroUsize, ) -> Result<Self, Error>

Create new context provider.

Note that if the sdk is None, the context provider will not be able to fetch data itself and will rely on values set by the user in the caches: data_contracts_cache, quorum_public_keys_cache.

Sdk can be set later with GrpcContextProvider::set_sdk.

pub fn set_sdk(&self, sdk: Option<Sdk>)

Set the Sdk to use when fetching data from Platform. This is useful when the Sdk is created after the ContextProvider.

Note that if the sdk is None, the context provider will not be able to fetch data itself and will rely on values set by the user in the caches: data_contracts_cache, quorum_public_keys_cache.

pub fn set_dump_dir(&mut self, dump_dir: Option<PathBuf>)

Set the directory where to store dumped data.

When set, the context provider will store data fetched from Platform into this directory.