pub struct GetAddressesBranchStateResponse {
pub version: Option<Version>,
}Fields
version: Option<Version>Trait Implementations
Sourceimpl Clone for GetAddressesBranchStateResponse
impl Clone for GetAddressesBranchStateResponse
Sourcefn clone(&self) -> GetAddressesBranchStateResponse
fn clone(&self) -> GetAddressesBranchStateResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for GetAddressesBranchStateResponse
impl Default for GetAddressesBranchStateResponse
Sourcefn default() -> GetAddressesBranchStateResponse
fn default() -> GetAddressesBranchStateResponse
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for GetAddressesBranchStateResponse
impl<'de> Deserialize<'de> for GetAddressesBranchStateResponse
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<GetAddressesBranchStateResponse, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<GetAddressesBranchStateResponse, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<GetAddressesBranchStateResponseV0> for GetAddressesBranchStateResponse
impl From<GetAddressesBranchStateResponseV0> for GetAddressesBranchStateResponse
Sourcefn from(
inner: GetAddressesBranchStateResponseV0,
) -> GetAddressesBranchStateResponse
fn from( inner: GetAddressesBranchStateResponseV0, ) -> GetAddressesBranchStateResponse
Converts to this type from the input type.
Sourceimpl MerkProofVersionedGrpcResponse for GetAddressesBranchStateResponse
impl MerkProofVersionedGrpcResponse for GetAddressesBranchStateResponse
type Error = PlatformVersionError
fn merk_proof( &self, ) -> Result<&Vec<u8>, <GetAddressesBranchStateResponse as MerkProofVersionedGrpcResponse>::Error>
fn merk_proof_owned( self, ) -> Result<Vec<u8>, <GetAddressesBranchStateResponse as MerkProofVersionedGrpcResponse>::Error>
Sourceimpl Message for GetAddressesBranchStateResponse
impl Message for GetAddressesBranchStateResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl Mockable for GetAddressesBranchStateResponse
impl Mockable for GetAddressesBranchStateResponse
Sourcefn mock_serialize(&self) -> Option<Vec<u8>>
fn mock_serialize(&self) -> Option<Vec<u8>>
Serialize the message to bytes for mocking purposes. Read more
Sourcefn mock_deserialize(data: &[u8]) -> Option<GetAddressesBranchStateResponse>
fn mock_deserialize(data: &[u8]) -> Option<GetAddressesBranchStateResponse>
Deserialize the message serialized with [mock_serialize()]. Read more
Sourceimpl PartialEq for GetAddressesBranchStateResponse
impl PartialEq for GetAddressesBranchStateResponse
Sourcefn eq(&self, other: &GetAddressesBranchStateResponse) -> bool
fn eq(&self, other: &GetAddressesBranchStateResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for GetAddressesBranchStateResponse
impl Serialize for GetAddressesBranchStateResponse
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Eq for GetAddressesBranchStateResponse
impl StructuralPartialEq for GetAddressesBranchStateResponse
impl VersionedGrpcMessage<GetAddressesBranchStateResponseV0> for GetAddressesBranchStateResponse