Struct GetContractGroupInfoRequest
pub struct GetContractGroupInfoRequest {
pub version: Option<Version>,
}Fields
version: Option<Version>Trait Implementations
impl Clone for GetContractGroupInfoRequest
impl Clone for GetContractGroupInfoRequest
fn clone(&self) -> GetContractGroupInfoRequest
fn clone(&self) -> GetContractGroupInfoRequest
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Debug for GetContractGroupInfoRequest
impl Debug for GetContractGroupInfoRequest
impl Default for GetContractGroupInfoRequest
impl Default for GetContractGroupInfoRequest
fn default() -> GetContractGroupInfoRequest
fn default() -> GetContractGroupInfoRequest
Returns the “default value” for a type. Read more
impl<'de> Deserialize<'de> for GetContractGroupInfoRequest
impl<'de> Deserialize<'de> for GetContractGroupInfoRequest
fn deserialize<__D>(
__deserializer: __D,
) -> Result<GetContractGroupInfoRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<GetContractGroupInfoRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for GetContractGroupInfoRequest
impl From<GetContractGroupInfoRequestV0> for GetContractGroupInfoRequest
impl From<GetContractGroupInfoRequestV0> for GetContractGroupInfoRequest
fn from(inner: GetContractGroupInfoRequestV0) -> GetContractGroupInfoRequest
fn from(inner: GetContractGroupInfoRequestV0) -> GetContractGroupInfoRequest
Converts to this type from the input type.
impl FromProof<GetContractGroupInfoRequest> for ContractGroupInfo
impl FromProof<GetContractGroupInfoRequest> for ContractGroupInfo
type Request = GetContractGroupInfoRequest
type Request = GetContractGroupInfoRequest
Request type for which this trait is implemented.
type Response = GetContractGroupInfoResponse
type Response = GetContractGroupInfoResponse
Response type for which this trait is implemented.
fn maybe_from_proof_with_metadata<'a, I, O>(
request: I,
response: O,
_network: Network,
platform_version: &PlatformVersion,
provider: &'a dyn ContextProvider,
) -> Result<(Option<ContractGroupInfo>, ResponseMetadata, Proof), Error>where
I: Into<<ContractGroupInfo as FromProof<GetContractGroupInfoRequest>>::Request>,
O: Into<<ContractGroupInfo as FromProof<GetContractGroupInfoRequest>>::Response>,
ContractGroupInfo: Sized + 'a,
fn maybe_from_proof_with_metadata<'a, I, O>(
request: I,
response: O,
_network: Network,
platform_version: &PlatformVersion,
provider: &'a dyn ContextProvider,
) -> Result<(Option<ContractGroupInfo>, ResponseMetadata, Proof), Error>where
I: Into<<ContractGroupInfo as FromProof<GetContractGroupInfoRequest>>::Request>,
O: Into<<ContractGroupInfo as FromProof<GetContractGroupInfoRequest>>::Response>,
ContractGroupInfo: Sized + 'a,
Parse and verify the received proof and retrieve the requested object, if any. Read more
fn maybe_from_proof<'a, I, O>(
request: I,
response: O,
network: Network,
platform_version: &PlatformVersion,
provider: &'a dyn ContextProvider,
) -> Result<Option<Self>, Error>
fn maybe_from_proof<'a, I, O>( request: I, response: O, network: Network, platform_version: &PlatformVersion, provider: &'a dyn ContextProvider, ) -> Result<Option<Self>, Error>
Parse and verify the received proof and retrieve the requested object, if any. Read more
fn from_proof<'a, I, O>(
request: I,
response: O,
network: Network,
platform_version: &PlatformVersion,
provider: &'a dyn ContextProvider,
) -> Result<Self, Error>
fn from_proof<'a, I, O>( request: I, response: O, network: Network, platform_version: &PlatformVersion, provider: &'a dyn ContextProvider, ) -> Result<Self, Error>
Retrieve the requested object from the proof. Read more
fn from_proof_with_metadata<'a, I, O>(
request: I,
response: O,
network: Network,
platform_version: &PlatformVersion,
provider: &'a dyn ContextProvider,
) -> Result<(Self, ResponseMetadata), Error>
fn from_proof_with_metadata<'a, I, O>( request: I, response: O, network: Network, platform_version: &PlatformVersion, provider: &'a dyn ContextProvider, ) -> Result<(Self, ResponseMetadata), Error>
Retrieve the requested object from the proof with metadata. Read more
fn from_proof_with_metadata_and_proof<'a, I, O>(
request: I,
response: O,
network: Network,
platform_version: &PlatformVersion,
provider: &'a dyn ContextProvider,
) -> Result<(Self, ResponseMetadata, Proof), Error>
fn from_proof_with_metadata_and_proof<'a, I, O>( request: I, response: O, network: Network, platform_version: &PlatformVersion, provider: &'a dyn ContextProvider, ) -> Result<(Self, ResponseMetadata, Proof), Error>
Retrieve the requested object from the proof with metadata. Read more
impl FromUnproved<GetContractGroupInfoRequest> for ContractGroupInfo
impl FromUnproved<GetContractGroupInfoRequest> for ContractGroupInfo
type Request = GetContractGroupInfoRequest
type Request = GetContractGroupInfoRequest
Request type for which this trait is implemented.
type Response = GetContractGroupInfoResponse
type Response = GetContractGroupInfoResponse
Response type for which this trait is implemented.
fn maybe_from_unproved_with_metadata<I, O>(
_request: I,
response: O,
_network: Network,
_platform_version: &PlatformVersion,
) -> Result<(Option<ContractGroupInfo>, ResponseMetadata), Error>where
I: Into<<ContractGroupInfo as FromUnproved<GetContractGroupInfoRequest>>::Request>,
O: Into<<ContractGroupInfo as FromUnproved<GetContractGroupInfoRequest>>::Response>,
ContractGroupInfo: Sized,
fn maybe_from_unproved_with_metadata<I, O>(
_request: I,
response: O,
_network: Network,
_platform_version: &PlatformVersion,
) -> Result<(Option<ContractGroupInfo>, ResponseMetadata), Error>where
I: Into<<ContractGroupInfo as FromUnproved<GetContractGroupInfoRequest>>::Request>,
O: Into<<ContractGroupInfo as FromUnproved<GetContractGroupInfoRequest>>::Response>,
ContractGroupInfo: Sized,
Parse the received response and retrieve the requested object along with metadata, if any. Read more
fn maybe_from_unproved<I, O>(
request: I,
response: O,
network: Network,
platform_version: &PlatformVersion,
) -> Result<Option<Self>, Error>
fn maybe_from_unproved<I, O>( request: I, response: O, network: Network, platform_version: &PlatformVersion, ) -> Result<Option<Self>, Error>
Parse the received response and retrieve the requested object, if any. Read more
fn from_unproved<I, O>(
request: I,
response: O,
network: Network,
platform_version: &PlatformVersion,
) -> Result<Self, Error>
fn from_unproved<I, O>( request: I, response: O, network: Network, platform_version: &PlatformVersion, ) -> Result<Self, Error>
Retrieve the requested object from the response. Read more
fn from_unproved_with_metadata<I, O>(
request: I,
response: O,
network: Network,
platform_version: &PlatformVersion,
) -> Result<(Self, ResponseMetadata), Error>
fn from_unproved_with_metadata<I, O>( request: I, response: O, network: Network, platform_version: &PlatformVersion, ) -> Result<(Self, ResponseMetadata), Error>
Retrieve the requested object from the response along with metadata. Read more
impl Hash for GetContractGroupInfoRequest
impl Hash for GetContractGroupInfoRequest
impl Message for GetContractGroupInfoRequest
impl Message for GetContractGroupInfoRequest
fn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl Mockable for GetContractGroupInfoRequest
impl Mockable for GetContractGroupInfoRequest
fn mock_serialize(&self) -> Option<Vec<u8>>
fn mock_serialize(&self) -> Option<Vec<u8>>
Serialize the message to bytes for mocking purposes. Read more
fn mock_deserialize(data: &[u8]) -> Option<GetContractGroupInfoRequest>
fn mock_deserialize(data: &[u8]) -> Option<GetContractGroupInfoRequest>
Deserialize the message serialized with [mock_serialize()]. Read more
impl PartialEq for GetContractGroupInfoRequest
impl PartialEq for GetContractGroupInfoRequest
fn eq(&self, other: &GetContractGroupInfoRequest) -> bool
fn eq(&self, other: &GetContractGroupInfoRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Query<GetContractGroupInfoRequest> for Identifier
impl Query<GetContractGroupInfoRequest> for Identifier
Sourcefn query(
&self,
settings: &QuerySettings<'_>,
) -> Result<GetContractGroupInfoRequest, Error>
fn query( &self, settings: &QuerySettings<'_>, ) -> Result<GetContractGroupInfoRequest, Error>
Convert the query into a wire-shape [
TransportRequest]. Read moreimpl Serialize for GetContractGroupInfoRequest
impl Serialize for GetContractGroupInfoRequest
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for GetContractGroupInfoRequest
impl TransportRequest for GetContractGroupInfoRequest
impl TransportRequest for GetContractGroupInfoRequest
const SETTINGS_OVERRIDES: RequestSettings
const SETTINGS_OVERRIDES: RequestSettings
Settings that will override DapiClient’s ones each time the request is executed.
type Client = PlatformClient<Channel>
type Client = PlatformClient<Channel>
A client specific to this type of transport.
type Response = GetContractGroupInfoResponse
type Response = GetContractGroupInfoResponse
Transport layer response.
fn method_name(&self) -> &'static str
fn method_name(&self) -> &'static str
gRPC method name
fn execute_transport<'c>(
self,
client: &'c mut <GetContractGroupInfoRequest as TransportRequest>::Client,
settings: &AppliedRequestSettings,
) -> Pin<Box<dyn Future<Output = Result<<GetContractGroupInfoRequest as TransportRequest>::Response, TransportError>> + Send + 'c>>
fn execute_transport<'c>( self, client: &'c mut <GetContractGroupInfoRequest as TransportRequest>::Client, settings: &AppliedRequestSettings, ) -> Pin<Box<dyn Future<Output = Result<<GetContractGroupInfoRequest as TransportRequest>::Response, TransportError>> + Send + 'c>>
Perform transport request asynchronously.
fn request_name(&self) -> &'static str
fn request_name(&self) -> &'static str
gRPC request name
fn response_name(&self) -> &'static str
fn response_name(&self) -> &'static str
gRPC response name
impl VersionedGrpcMessage<GetContractGroupInfoRequestV0> for GetContractGroupInfoRequest
impl WireQuery for GetContractGroupInfoRequest