pub struct GetTokenPreProgrammedDistributionsRequest {
pub version: Option<Version>,
}Fields
version: Option<Version>Trait Implementations
Sourceimpl Clone for GetTokenPreProgrammedDistributionsRequest
impl Clone for GetTokenPreProgrammedDistributionsRequest
Sourcefn clone(&self) -> GetTokenPreProgrammedDistributionsRequest
fn clone(&self) -> GetTokenPreProgrammedDistributionsRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for GetTokenPreProgrammedDistributionsRequest
impl Default for GetTokenPreProgrammedDistributionsRequest
Sourcefn default() -> GetTokenPreProgrammedDistributionsRequest
fn default() -> GetTokenPreProgrammedDistributionsRequest
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for GetTokenPreProgrammedDistributionsRequest
impl<'de> Deserialize<'de> for GetTokenPreProgrammedDistributionsRequest
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<GetTokenPreProgrammedDistributionsRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<GetTokenPreProgrammedDistributionsRequest, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<GetTokenPreProgrammedDistributionsRequestV0> for GetTokenPreProgrammedDistributionsRequest
impl From<GetTokenPreProgrammedDistributionsRequestV0> for GetTokenPreProgrammedDistributionsRequest
Sourcefn from(
inner: GetTokenPreProgrammedDistributionsRequestV0,
) -> GetTokenPreProgrammedDistributionsRequest
fn from( inner: GetTokenPreProgrammedDistributionsRequestV0, ) -> GetTokenPreProgrammedDistributionsRequest
Converts to this type from the input type.
impl FromProof<GetTokenPreProgrammedDistributionsRequest> for TokenPreProgrammedDistributions
impl FromProof<GetTokenPreProgrammedDistributionsRequest> for TokenPreProgrammedDistributions
type Request = GetTokenPreProgrammedDistributionsRequest
type Request = GetTokenPreProgrammedDistributionsRequest
Request type for which this trait is implemented.
type Response = GetTokenPreProgrammedDistributionsResponse
type Response = GetTokenPreProgrammedDistributionsResponse
Response type for which this trait is implemented.
fn maybe_from_proof_with_metadata<'a, I, O>(
request: I,
response: O,
_network: Network,
platform_version: &PlatformVersion,
provider: &'a dyn ContextProvider,
) -> Result<(Option<TokenPreProgrammedDistributions>, ResponseMetadata, Proof), Error>where
I: Into<<TokenPreProgrammedDistributions as FromProof<GetTokenPreProgrammedDistributionsRequest>>::Request>,
O: Into<<TokenPreProgrammedDistributions as FromProof<GetTokenPreProgrammedDistributionsRequest>>::Response>,
TokenPreProgrammedDistributions: Sized + 'a,
fn maybe_from_proof_with_metadata<'a, I, O>(
request: I,
response: O,
_network: Network,
platform_version: &PlatformVersion,
provider: &'a dyn ContextProvider,
) -> Result<(Option<TokenPreProgrammedDistributions>, ResponseMetadata, Proof), Error>where
I: Into<<TokenPreProgrammedDistributions as FromProof<GetTokenPreProgrammedDistributionsRequest>>::Request>,
O: Into<<TokenPreProgrammedDistributions as FromProof<GetTokenPreProgrammedDistributionsRequest>>::Response>,
TokenPreProgrammedDistributions: Sized + 'a,
Parse and verify the received proof and retrieve the requested object, if any. Read more
fn maybe_from_proof<'a, I, O>(
request: I,
response: O,
network: Network,
platform_version: &PlatformVersion,
provider: &'a dyn ContextProvider,
) -> Result<Option<Self>, Error>
fn maybe_from_proof<'a, I, O>( request: I, response: O, network: Network, platform_version: &PlatformVersion, provider: &'a dyn ContextProvider, ) -> Result<Option<Self>, Error>
Parse and verify the received proof and retrieve the requested object, if any. Read more
fn from_proof<'a, I, O>(
request: I,
response: O,
network: Network,
platform_version: &PlatformVersion,
provider: &'a dyn ContextProvider,
) -> Result<Self, Error>
fn from_proof<'a, I, O>( request: I, response: O, network: Network, platform_version: &PlatformVersion, provider: &'a dyn ContextProvider, ) -> Result<Self, Error>
Retrieve the requested object from the proof. Read more
fn from_proof_with_metadata<'a, I, O>(
request: I,
response: O,
network: Network,
platform_version: &PlatformVersion,
provider: &'a dyn ContextProvider,
) -> Result<(Self, ResponseMetadata), Error>
fn from_proof_with_metadata<'a, I, O>( request: I, response: O, network: Network, platform_version: &PlatformVersion, provider: &'a dyn ContextProvider, ) -> Result<(Self, ResponseMetadata), Error>
Retrieve the requested object from the proof with metadata. Read more
fn from_proof_with_metadata_and_proof<'a, I, O>(
request: I,
response: O,
network: Network,
platform_version: &PlatformVersion,
provider: &'a dyn ContextProvider,
) -> Result<(Self, ResponseMetadata, Proof), Error>
fn from_proof_with_metadata_and_proof<'a, I, O>( request: I, response: O, network: Network, platform_version: &PlatformVersion, provider: &'a dyn ContextProvider, ) -> Result<(Self, ResponseMetadata, Proof), Error>
Retrieve the requested object from the proof with metadata. Read more
Sourceimpl Message for GetTokenPreProgrammedDistributionsRequest
impl Message for GetTokenPreProgrammedDistributionsRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl Mockable for GetTokenPreProgrammedDistributionsRequest
impl Mockable for GetTokenPreProgrammedDistributionsRequest
Sourcefn mock_serialize(&self) -> Option<Vec<u8>>
fn mock_serialize(&self) -> Option<Vec<u8>>
Serialize the message to bytes for mocking purposes. Read more
Sourcefn mock_deserialize(
data: &[u8],
) -> Option<GetTokenPreProgrammedDistributionsRequest>
fn mock_deserialize( data: &[u8], ) -> Option<GetTokenPreProgrammedDistributionsRequest>
Deserialize the message serialized with [mock_serialize()]. Read more
Sourceimpl PartialEq for GetTokenPreProgrammedDistributionsRequest
impl PartialEq for GetTokenPreProgrammedDistributionsRequest
Sourcefn eq(&self, other: &GetTokenPreProgrammedDistributionsRequest) -> bool
fn eq(&self, other: &GetTokenPreProgrammedDistributionsRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Query<GetTokenPreProgrammedDistributionsRequest> for TokenPreProgrammedDistributionsQuery
impl Query<GetTokenPreProgrammedDistributionsRequest> for TokenPreProgrammedDistributionsQuery
Sourceimpl Serialize for GetTokenPreProgrammedDistributionsRequest
impl Serialize for GetTokenPreProgrammedDistributionsRequest
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
Sourceimpl TransportRequest for GetTokenPreProgrammedDistributionsRequest
impl TransportRequest for GetTokenPreProgrammedDistributionsRequest
Sourceconst SETTINGS_OVERRIDES: RequestSettings
const SETTINGS_OVERRIDES: RequestSettings
Settings that will override DapiClient’s ones each time the request is executed.
Sourcetype Client = PlatformClient<Channel>
type Client = PlatformClient<Channel>
A client specific to this type of transport.
Sourcetype Response = GetTokenPreProgrammedDistributionsResponse
type Response = GetTokenPreProgrammedDistributionsResponse
Transport layer response.
Sourcefn method_name(&self) -> &'static str
fn method_name(&self) -> &'static str
gRPC method name
Sourcefn execute_transport<'c>(
self,
client: &'c mut <GetTokenPreProgrammedDistributionsRequest as TransportRequest>::Client,
settings: &AppliedRequestSettings,
) -> Pin<Box<dyn Future<Output = Result<<GetTokenPreProgrammedDistributionsRequest as TransportRequest>::Response, TransportError>> + Send + 'c>>
fn execute_transport<'c>( self, client: &'c mut <GetTokenPreProgrammedDistributionsRequest as TransportRequest>::Client, settings: &AppliedRequestSettings, ) -> Pin<Box<dyn Future<Output = Result<<GetTokenPreProgrammedDistributionsRequest as TransportRequest>::Response, TransportError>> + Send + 'c>>
Perform transport request asynchronously.
Sourcefn request_name(&self) -> &'static str
fn request_name(&self) -> &'static str
gRPC request name
Sourcefn response_name(&self) -> &'static str
fn response_name(&self) -> &'static str
gRPC response name
impl Eq for GetTokenPreProgrammedDistributionsRequest
impl StructuralPartialEq for GetTokenPreProgrammedDistributionsRequest
impl VersionedGrpcMessage<GetTokenPreProgrammedDistributionsRequestV0> for GetTokenPreProgrammedDistributionsRequest