pub trait WithdrawShielded {
// Required method
fn withdraw_shielded<'life0, 'async_trait>(
&'life0 self,
unshielding_amount: u64,
bundle: OrchardBundleParams,
core_fee_per_byte: u32,
pooling: Pooling,
output_script: CoreScript,
settings: Option<PutSettings>,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
}Expand description
Helper trait to withdraw funds from the shielded pool to L1.
Required Methods
Sourcefn withdraw_shielded<'life0, 'async_trait>(
&'life0 self,
unshielding_amount: u64,
bundle: OrchardBundleParams,
core_fee_per_byte: u32,
pooling: Pooling,
output_script: CoreScript,
settings: Option<PutSettings>,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn withdraw_shielded<'life0, 'async_trait>(
&'life0 self,
unshielding_amount: u64,
bundle: OrchardBundleParams,
core_fee_per_byte: u32,
pooling: Pooling,
output_script: CoreScript,
settings: Option<PutSettings>,
) -> Pin<Box<dyn Future<Output = Result<(), Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Withdraw funds from the shielded pool to a Core address. Authentication is via Orchard spend authorization signatures in the bundle actions.