pub trait TopUpAddress<S: Signer<PlatformAddress>> {
// Required method
fn top_up<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
sdk: &'life1 Sdk,
asset_lock_proof: AssetLockProof,
asset_lock_private_key: PrivateKey,
fee_strategy: AddressFundsFeeStrategy,
signer: &'life2 S,
settings: Option<PutSettings>,
) -> Pin<Box<dyn Future<Output = Result<AddressInfos, Error>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait;
}Expand description
Trait for topping up Platform addresses using various funding sources.
Required Methods
Sourcefn top_up<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
sdk: &'life1 Sdk,
asset_lock_proof: AssetLockProof,
asset_lock_private_key: PrivateKey,
fee_strategy: AddressFundsFeeStrategy,
signer: &'life2 S,
settings: Option<PutSettings>,
) -> Pin<Box<dyn Future<Output = Result<AddressInfos, Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
fn top_up<'life0, 'life1, 'life2, 'async_trait>(
&'life0 self,
sdk: &'life1 Sdk,
asset_lock_proof: AssetLockProof,
asset_lock_private_key: PrivateKey,
fee_strategy: AddressFundsFeeStrategy,
signer: &'life2 S,
settings: Option<PutSettings>,
) -> Pin<Box<dyn Future<Output = Result<AddressInfos, Error>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
'life2: 'async_trait,
Tops up addresses using the provided funding source and fee strategy.
Returns proof-backed AddressInfos for the funded addresses.