AddressList

Struct AddressList 

pub struct AddressList { /* private fields */ }
A structure to manage DAPI addresses to select from for DapiRequest execution.

Implementations

Source

impl AddressList

pub fn new() -> AddressList

Creates an empty AddressList with default base ban time.

pub fn with_settings(base_ban_period: Duration) -> AddressList

Creates an empty AddressList with adjustable base ban time.

pub fn ban(&self, address: &Address) -> bool

Bans address Returns false if the address is not in the list.

pub fn unban(&self, address: &Address) -> bool

Clears address’ ban record Returns false if the address is not in the list.

pub fn is_banned(&self, address: &Address) -> bool

Check if the address is banned.

pub fn add(&mut self, address: Address) -> bool

Adds a node Address to AddressList Returns false if the address is already in the list.

pub fn remove(&mut self, address: &Address) -> Option<AddressStatus>

Remove address from the list Returns AddressStatus if the address was in the list.

pub fn add_uri(&mut self, uri: Uri) -> bool

👎Deprecated

Add a node Address to AddressList by Uri. Returns false if the address is already in the list.

pub fn get_live_address(&self) -> Option<Address>

Randomly select a not banned address.

pub fn get_live_addresses(&self) -> Vec<Address>

Get all not banned addresses.

Returns a vector of addresses that are not currently banned or whose ban period has expired. The returned addresses use the same filtering logic as [get_live_address], checking if the ban period has expired based on the current time.

Examples
use rs_dapi_client::{AddressList, Address};

let mut list = AddressList::new();
list.add("http://127.0.0.1:3000".parse().unwrap());
list.add("http://127.0.0.1:3001".parse().unwrap());

// Get all non-banned addresses
let live_addresses = list.get_live_addresses();
assert_eq!(live_addresses.len(), 2);
pub fn len(&self) -> usize

Get number of all addresses, both banned and not banned.

pub fn is_empty(&self) -> bool

Check if the list is empty. Returns true if there are no addresses in the list. Returns false if there is at least one address in the list. Banned addresses are also counted.