pub struct AddressList { /* private fields */ }Expand description
A structure to manage DAPI addresses to select from for DapiRequest execution.
Implementations
Sourceimpl AddressList
impl AddressList
Sourcepub fn new() -> AddressList
pub fn new() -> AddressList
Creates an empty AddressList with default base ban time.
Sourcepub fn with_settings(base_ban_period: Duration) -> AddressList
pub fn with_settings(base_ban_period: Duration) -> AddressList
Creates an empty AddressList with adjustable base ban time.
Sourcepub fn ban(&self, address: &Address) -> bool
pub fn ban(&self, address: &Address) -> bool
Bans address Returns false if the address is not in the list.
Sourcepub fn unban(&self, address: &Address) -> bool
pub fn unban(&self, address: &Address) -> bool
Clears address’ ban record Returns false if the address is not in the list.
Sourcepub fn add(&mut self, address: Address) -> bool
pub fn add(&mut self, address: Address) -> bool
Adds a node Address to AddressList Returns false if the address is already in the list.
Sourcepub fn remove(&mut self, address: &Address) -> Option<AddressStatus>
pub fn remove(&mut self, address: &Address) -> Option<AddressStatus>
Remove address from the list Returns AddressStatus if the address was in the list.
Sourcepub fn add_uri(&mut self, uri: Uri) -> bool
👎Deprecated
pub fn add_uri(&mut self, uri: Uri) -> bool
Add a node Address to AddressList by Uri. Returns false if the address is already in the list.
Sourcepub fn get_live_address(&self) -> Option<Address>
pub fn get_live_address(&self) -> Option<Address>
Randomly select a not banned address.
Sourcepub fn get_live_addresses(&self) -> Vec<Address>
pub fn get_live_addresses(&self) -> Vec<Address>
Get all not banned addresses.
Returns a vector of addresses that are not currently banned or whose ban period has expired. The returned addresses use the same filtering logic as [get_live_address], checking if the ban period has expired based on the current time.
Examples
use rs_dapi_client::{AddressList, Address};
let mut list = AddressList::new();
list.add("http://127.0.0.1:3000".parse().unwrap());
list.add("http://127.0.0.1:3001".parse().unwrap());
// Get all non-banned addresses
let live_addresses = list.get_live_addresses();
assert_eq!(live_addresses.len(), 2);Trait Implementations
Sourceimpl Clone for AddressList
impl Clone for AddressList
Sourcefn clone(&self) -> AddressList
fn clone(&self) -> AddressList
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for AddressList
impl Debug for AddressList
Sourceimpl Default for AddressList
impl Default for AddressList
Sourcefn default() -> AddressList
fn default() -> AddressList
Sourceimpl FromIterator<Address> for AddressList
impl FromIterator<Address> for AddressList
Sourcefn from_iter<T>(iter: T) -> AddressListwhere
T: IntoIterator<Item = Address>,
fn from_iter<T>(iter: T) -> AddressListwhere
T: IntoIterator<Item = Address>,
Sourceimpl FromStr for AddressList
impl FromStr for AddressList
Sourcetype Err = AddressListError
type Err = AddressListError
Sourcefn from_str(s: &str) -> Result<AddressList, <AddressList as FromStr>::Err>
fn from_str(s: &str) -> Result<AddressList, <AddressList as FromStr>::Err>
s to return a value of this type. Read moreSourceimpl IntoIterator for AddressList
impl IntoIterator for AddressList
Sourcetype Item = (Address, AddressStatus)
type Item = (Address, AddressStatus)
Sourcetype IntoIter = IntoIter<Address, AddressStatus>
type IntoIter = IntoIter<Address, AddressStatus>
Sourcefn into_iter(self) -> <AddressList as IntoIterator>::IntoIter
fn into_iter(self) -> <AddressList as IntoIterator>::IntoIter